@@ -1,6 +1,6 @@
 package Git::Hooks;
 # ABSTRACT: Framework for implementing Git (and Gerrit) hooks
-$Git::Hooks::VERSION = '1.12.5';
+$Git::Hooks::VERSION = '1.13.0';
 use 5.010;
 use strict;
 use warnings;
@@ -8,6 +8,7 @@ use Carp;
 use Exporter qw/import/;
 use Sub::Util qw/subname/;
 use Path::Tiny;
+use List::MoreUtils qw/any/;
 
 our (@EXPORT, @EXPORT_OK, %EXPORT_TAGS); ## no critic (Modules::ProhibitAutomaticExportation)
 my (%Hooks, @PostHooks);
@@ -426,46 +427,63 @@ sub _prepare_gerrit_ref_update {
 sub _gerrit_patchset_post_hook {
     my ($hook_name, $git, $args) = @_;
 
-    my $resource = do {
-        for my $arg (qw/project branch change patchset/) {
-            exists $args->{"--$arg"}
-                or die __PACKAGE__, ": Missing --$arg argument to Gerrit's $hook_name hook.\n"
-        }
-
-        # We have to use the most complete form of Gerrit change ids because
-        # it's the only unanbiguous one. Vide:
-        # https://gerrit.cpqd.com.br/Documentation/rest-api-changes.html#change-id.
-
-        # Also, we have to escape it because the project name may contain
-        # slashes (and perhaps other reserved characters). This is possibly
-        # not a complete solution. Vide:
-        # http://mark.stosberg.com/blog/2010/12/percent-encoding-uris-in-perl.html.
-        require URI::Escape;
-        my $id = URI::Escape::uri_escape(
-            join('~', @{$args}{qw/--project --branch --change/}),
-        );
-
-        my $patchset = $args->{'--patchset'};
-
-        "/changes/$id/revisions/$patchset/review";
-    };
-
-    my $review_label = $git->get_config('githooks.gerrit' => 'review-label') || 'Code-Review';
-
-    my %params;
-
-    if (my @errors = $git->get_errors()) {
-        $params{labels}  = { $review_label => $git->get_config('githooks.gerrit' => 'vote-nok') || -1 };
-        $params{message} = join("\n\n", @errors);
-    } else {
-        $params{labels}  = { $review_label => $git->get_config('githooks.gerrit' => 'vote-ok')  || +1 };
-        if (my $comment = $git->get_config('githooks.gerrit' => 'comment-ok')) {
-            $params{message} = "[Git::Hooks] $comment";
-        }
+    for my $arg (qw/project branch change patchset/) {
+        exists $args->{"--$arg"}
+            or die __PACKAGE__, ": Missing --$arg argument to Gerrit's $hook_name hook.\n";
     }
 
-    eval { $args->{gerrit}->POST($resource, \%params) }
-        or die __PACKAGE__ . ": error in Gerrit::REST::POST($resource): $@\n";
+    # We have to use the most complete form of Gerrit change ids because
+    # it's the only unanbiguous one. Vide:
+    # https://gerrit.cpqd.com.br/Documentation/rest-api-changes.html#change-id.
+
+    # Also, we have to escape it because the project name may contain
+    # slashes (and perhaps other reserved characters). This is possibly not
+    # a complete solution. Vide:
+    # http://mark.stosberg.com/blog/2010/12/percent-encoding-uris-in-perl.html.
+    require URI::Escape;
+    my $id = URI::Escape::uri_escape(join('~', @{$args}{qw/--project --branch --change/}));
+
+    my $patchset = $args->{'--patchset'};
+
+    # Grok all configuration options at once to make it easier to deal with them below.
+    my %cfg = map {$_ => $git->get_config('githooks.gerrit' => $_) || undef}
+        qw/review-label vote-nok vote-ok votes-to-approve votes-to-reject comment-ok auto-submit/;
+
+    # Convert DEPRECATED configuration options to new ones.
+    if (any {defined $cfg{$_}} qw/review-label vote-nok vote-ok/) {
+        if (any {defined $cfg{$_}} qw/votes-to-approve votes-to-reject/) {
+            die __PACKAGE__ . ": Mixing deprecated githooks.gerrit configuration options (review-label vote-nok vote-ok) with new ones (votes-to-approve votes-to-reject) is not permited. Please, convert the deprecated ones.\n"
+        }
+        $cfg{'votes-to-approve'} = $cfg{'votes-to-reject'} = $cfg{'review-label'} || 'Code-Review';
+        $cfg{'votes-to-reject'} .= $cfg{'vote-nok'} || '-1';
+        $cfg{'votes-to-approve'} .= $cfg{'vote-ok'}  || '+1';
+    }
+
+    my %params;
+    my $auto_submit = 0;
+
+    if (my @errors = $git->get_errors()) {
+        $params{labels}  = $cfg{'votes-to-reject'} || 'Code-Review-1';
+        $params{message} = join("\n\n", @errors);
+    } else {
+        $params{labels}  = $cfg{'votes-to-approve'} || 'Code-Review+1';
+        $params{message} = "[Git::Hooks] $cfg{'comment-ok'}"
+            if $cfg{'comment-ok'};
+        $auto_submit = 1 if $cfg{'auto-submit'};
+    }
+
+    # Convert, e.g., 'LabelA-1,LabelB+2' into { LabelA => '-1', LabelB => '+2' }
+    $params{labels} = { map {/^([-\w]+)([-+]\d+)$/i} split(',', $params{labels}) };
+
+    # Cast review
+    eval { $args->{gerrit}->POST("/changes/$id/revisions/$patchset/review", \%params) }
+        or die __PACKAGE__ . ": error in Gerrit::REST::POST(/changes/$id/revisions/$patchset/review): $@\n";
+
+    # Auto submit if requested and passed verification
+    if ($auto_submit) {
+        eval { $args->{gerrit}->POST("/changes/$id/submit", {wait_for_merge => 'true'}) }
+            or die __PACKAGE__ . ": I couldn't submit the change. Perhaps you have to rebase it manually to resolve a conflict. Please go to its web page to check it out. The error message follows: $@\n";
+    }
 
     return;
 }
@@ -690,7 +708,7 @@ Git::Hooks - Framework for implementing Git (and Gerrit) hooks
 
 =head1 VERSION
 
-version 1.12.5
+version 1.13.0
 
 =head1 SYNOPSIS
 
@@ -1352,22 +1370,37 @@ These three options are required if you enable Gerrit hooks. They are
 used to construct the C<Gerrit::REST> object that is used to interact
 with Gerrit.
 
-=head2 githooks.gerrit.review-label LABEL
+=head2 githooks.gerrit.votes-to-approve VOTES
 
-This option defines the
-L<label|https://gerrit-review.googlesource.com/Documentation/config-labels.html>
-that must be used in Gerrit's review process. If not specified, the standard
-C<Code-Review> label is used.
+This option defines which votes should be cast in which
+L<labels|https://gerrit-review.googlesource.com/Documentation/config-labels.html>
+to B<approve> a review in the Gerrit change when all verification hooks
+pass.
 
-=head2 githooks.gerrit.vote-ok +N
+VOTES is a comma-separated list of LABEL and VOTE mappings, such as:
 
-This option defines the vote that must be used to approve a review. If
-not specified, +1 is used.
+  Code-Review+2,Verification+1
 
-=head2 githooks.gerrit.vote-nok -N
+Which means that the C<Code-Review> label should receive a +2 and the label
+C<Verification> should receive a +1.
 
-This option defines the vote that must be used to reject a review. If
-not specified, -1 is used.
+If not specified, the default VOTES is:
+
+  Code-Review+1
+
+=head2 githooks.gerrit.votes-to-reject VOTES
+
+This option defines which votes should be cast in which
+L<labels|https://gerrit-review.googlesource.com/Documentation/config-labels.html>
+to B<reject> a review in the Gerrit change when some verification hooks
+fail.
+
+VOTES has the same syntax as described for the
+C<githooks.gerrit.votes-to-approve> option above.
+
+If not specified, the default VOTES is:
+
+  Code-Review-1
 
 =head2 githooks.gerrit.comment-ok COMMENT
 
@@ -1379,6 +1412,47 @@ a comment like this in addition to casting the vote:
 
 You may want to use a simple comment like 'OK'.
 
+=head2 githooks.gerrit.auto-submit [01]
+
+If this option is enabled, Git::Hooks will try to automatically submit a
+change if all verification hooks pass.
+
+Note that for the submission to succeed you must vote with
+C<githooks.gerrit.votes-to-approve> so that the change has the necessary
+votes to be submitted. Moreover, the C<username> and C<password> you
+configured above must have the necessary rights to submit the change in
+Gerrit.
+
+This may be useful to provide a gentle introduction to Gerrit for people who
+don't want to start doing code reviews but want to use Gerrit simply as a
+Git server.
+
+=head2 githooks.gerrit.review-label LABEL
+
+This option is DEPRECATED. Please, use C<githooks.gerrit.votes-to-approve> and
+C<githooks.gerrit.votes-to-reject> instead.
+
+This option defines the
+L<label|https://gerrit-review.googlesource.com/Documentation/config-labels.html>
+that must be used in Gerrit's review process. If not specified, the standard
+C<Code-Review> label is used.
+
+=head2 githooks.gerrit.vote-ok +N
+
+This option is DEPRECATED. Please, use C<githooks.gerrit.votes-to-approve> and
+C<githooks.gerrit.votes-to-reject> instead.
+
+This option defines the vote that must be used to approve a review. If
+not specified, +1 is used.
+
+=head2 githooks.gerrit.vote-nok -N
+
+This option is DEPRECATED. Please, use C<githooks.gerrit.votes-to-approve> and
+C<githooks.gerrit.votes-to-reject> instead.
+
+This option defines the vote that must be used to reject a review. If
+not specified, -1 is used.
+
 =head2 githooks.help-on-error MESSAGE
 
 This option allows you to specify a helpful message that will be shown if
